pub fn format_page(format: FileFormat) -> &'static strExpand description
The family page and heading that describe a format, from docs/formats/.
pub fn format_page(format: FileFormat) -> &'static strThe family page and heading that describe a format, from docs/formats/.