pub fn short_title(format: FileFormat) -> &'static strExpand description
A format’s name in a list of them: its title, or a plain name for audio and text.
pub fn short_title(format: FileFormat) -> &'static strA format’s name in a list of them: its title, or a plain name for audio and text.