pub enum Compressed {
Refused,
Decompressed,
ReadThrough,
}Expand description
How a compressed file of a format is read.
Variants
Refused
It is not: the open refuses it.
Decompressed
Decompressed once, to a file or with [file_loading] decompress_in_memory into memory.
ReadThrough
Decompressed as it is read into the files it is converted to.