pub enum ThemeAction {
List,
Show {
name: String,
},
}Expand description
What datui theme does.
Variants
List
List the themes: name, the mode it is set for, where it comes from and its description
Show
Print a theme as a file with every slot, to save into themes/ and edit